@@ -1,4 +1,5 @@
 import json
+import os
 import pathlib
 
 import httpx
@@ -21,9 +22,9 @@ def product_url(ctx: typer.Context) -> str:
 @app.command(name="create")
 def create_from_json(
     ctx: typer.Context,
-    name: str = typer.Argument(..., help="Data Product name"),
-    engine: str = typer.Argument(..., help="Storage engine"),
-    filepath: str = typer.Argument(..., help="Filepath of the table schema json payload"),
+    name: str = typer.Argument(os.getenv("NEOSCTL_PRODUCT", ...), help="Data Product name"),
+    engine: str = typer.Option(..., "--engine", "-e", help="Storage engine"),
+    filepath: str = typer.Option(..., "--filepath", "-f", help="Filepath of the table schema json payload"),
 ):
     """Create a data product.
     """
@@ -70,7 +71,10 @@ def list(ctx: typer.Context):
 
 
 @app.command()
-def delete_data(ctx: typer.Context, name: str):
+def delete_data(
+    ctx: typer.Context,
+    name: str = typer.Argument(os.getenv("NEOSCTL_PRODUCT", ...), help="Data Product name"),
+):
     """Delete data from a data product.
     """
     @ensure_login
@@ -85,7 +89,10 @@ def delete_data(ctx: typer.Context, name: str):
 
 
 @app.command()
-def delete(ctx: typer.Context, name: str):
+def delete(
+    ctx: typer.Context,
+    name: str = typer.Argument(os.getenv("NEOSCTL_PRODUCT", ...), help="Data Product name"),
+):
     """Delete a data product.
     """
     @ensure_login
@@ -100,7 +107,10 @@ def delete(ctx: typer.Context, name: str):
 
 
 @app.command()
-def publish(ctx: typer.Context, name: str):
+def publish(
+    ctx: typer.Context,
+    name: str = typer.Argument(os.getenv("NEOSCTL_PRODUCT", ...), help="Data Product name"),
+):
     """Publish a data product.
     """
     @ensure_login
@@ -115,7 +125,10 @@ def publish(ctx: typer.Context, name: str):
 
 
 @app.command()
-def unpublish(ctx: typer.Context, name: str):
+def unpublish(
+    ctx: typer.Context,
+    name: str = typer.Argument(os.getenv("NEOSCTL_PRODUCT", ...), help="Data Product name"),
+):
     """Unpublish a product.
     """
     @ensure_login
@@ -130,7 +143,10 @@ def unpublish(ctx: typer.Context, name: str):
 
 
 @app.command(name="schema")
-def get_schema(ctx: typer.Context, product_name: str):
+def get_schema(
+    ctx: typer.Context,
+    product_name: str = typer.Argument(os.getenv("NEOSCTL_PRODUCT", ...), help="Data Product name"),
+):
     """Get data product schema.
     """
     @ensure_login
@@ -147,7 +163,7 @@ def get_schema(ctx: typer.Context, product_name: str):
 @app.command()
 def preview(
     ctx: typer.Context,
-    product_name: str,
+    product_name: str = typer.Argument(os.getenv("NEOSCTL_PRODUCT", ...), help="Data Product name"),
 ):
     """Preview data product data.
 
