@@ -1,3 +1,4 @@
+import os
 import pathlib
 import typing
 
@@ -26,7 +27,7 @@ def secret_url(name: str, gateway_api_url: str) -> str:
 @app.command()
 def add_job(
     ctx: typer.Context,
-    product_name: str,
+    product_name: str = typer.Argument(os.getenv("NEOSCTL_PRODUCT", ...), help="Data Product name"),
     job_filepath: str = typer.Option(..., "--job-filepath", "-f"),
     docker_tag: str = typer.Option("v0.1.34", "--docker-tag", "-d"),
     executor_cores: int = typer.Option(1, "--executor-cores", "-ec"),
@@ -74,7 +75,10 @@ def add_job(
 
 
 @app.command()
-def job_status(ctx: typer.Context, product_name: str):
+def job_status(
+    ctx: typer.Context,
+    product_name: str = typer.Argument(os.getenv("NEOSCTL_PRODUCT", ...), help="Data Product name"),
+):
     """Get current status of a spark job.
     """
     @ensure_login
@@ -93,7 +97,10 @@ def render_logs(payload: typing.Dict):
 
 
 @app.command()
-def job_logs(ctx: typer.Context, product_name: str):
+def job_logs(
+    ctx: typer.Context,
+    product_name: str = typer.Argument(os.getenv("NEOSCTL_PRODUCT", ...), help="Data Product name"),
+):
     """Get logs for a spark job.
     """
     @ensure_login
@@ -110,7 +117,7 @@ def job_logs(ctx: typer.Context, product_name: str):
 @app.command()
 def update_job(
     ctx: typer.Context,
-    product_name: str,
+    product_name: str = typer.Argument(os.getenv("NEOSCTL_PRODUCT", ...), help="Data Product name"),
     job_filepath: str = typer.Option(None, "--job-filepath", "-f"),
     docker_tag: str = typer.Option(None, "--docker-tag", "-d"),
     executor_cores: int = typer.Option(None, "--executor-cores", "-ec"),
@@ -170,7 +177,10 @@ def update_job(
 
 
 @app.command()
-def remove_job(ctx: typer.Context, product_name: str):
+def remove_job(
+    ctx: typer.Context,
+    product_name: str = typer.Argument(os.getenv("NEOSCTL_PRODUCT", ...), help="Data Product name"),
+):
     """Remove assigned spark job.
     """
     @ensure_login
@@ -185,7 +195,10 @@ def remove_job(ctx: typer.Context, product_name: str):
 
 
 @app.command()
-def trigger_job(ctx: typer.Context, product_name: str):
+def trigger_job(
+    ctx: typer.Context,
+    product_name: str = typer.Argument(os.getenv("NEOSCTL_PRODUCT", ...), help="Data Product name"),
+):
     """Trigger assigned spark job.
 
     Trigger an additional run of a spark job.
@@ -204,7 +217,7 @@ def trigger_job(ctx: typer.Context, product_name: str):
 @app.command()
 def schedule_job(
     ctx: typer.Context,
-    product_name: str = typer.Option(..., "--product-name", "-pn"),
+    product_name: str = typer.Argument(os.getenv("NEOSCTL_PRODUCT", ...), help="Data Product name"),
     schedule: str = typer.Option(..., "--schedule", "-s", help='Schedule in crontab format (e.g. "* * * * *")'),
 ):
     """Schedule an assigned spark job.
@@ -228,7 +241,7 @@ def schedule_job(
 @secret_app.command()
 def add(
     ctx: typer.Context,
-    product_name: str,
+    product_name: str = typer.Argument(os.getenv("NEOSCTL_PRODUCT", ...), help="Data Product name"),
     secrets: typing.List[str] = typer.Option(..., "--secret", "-s", help="Secret in the form key:value"),
 ):
     """Add a set of secrets for a spark job.
@@ -253,7 +266,7 @@ def add(
 @secret_app.command()
 def update(
     ctx: typer.Context,
-    product_name: str,
+    product_name: str = typer.Argument(os.getenv("NEOSCTL_PRODUCT", ...), help="Data Product name"),
     secrets: typing.List[str] = typer.Option(..., "--secret", "-s", help="Secret in the form key:value"),
 ):
     """Update existing secrets.
@@ -281,7 +294,7 @@ def update(
 @secret_app.command()
 def remove(
     ctx: typer.Context,
-    product_name: str,
+    product_name: str = typer.Argument(os.getenv("NEOSCTL_PRODUCT", ...), help="Data Product name"),
 ):
     """Remove secret.
     """
@@ -300,7 +313,7 @@ def remove(
 @secret_app.command()
 def remove_key(
     ctx: typer.Context,
-    product_name: str,
+    product_name: str = typer.Argument(os.getenv("NEOSCTL_PRODUCT", ...), help="Data Product name"),
     keys: typing.List[str] = typer.Option(..., "--key", "-k", help="Key name you wish to remove from secret"),
 ):
     """Remove a set of keys from a secret.
@@ -321,7 +334,7 @@ def remove_key(
 @secret_app.command()
 def get(
     ctx: typer.Context,
-    product_name: str,
+    product_name: str = typer.Argument(os.getenv("NEOSCTL_PRODUCT", ...), help="Data Product name"),
 ):
     """Get existing secret keys.
     """
