@@ -62,12 +62,11 @@ def get_schema_profile(profile_name, allow_missing: bool = False, **kwargs):
         return schema.Profile(**kwargs)
     except pydantic.ValidationError as e:
         required_fields = [err["loc"][0] for err in e.errors() if err["msg"] == "field required"]
-        field_names = ", ".join(required_fields)
         send_output(
             msg=(
-                "Profile dotfile doesn't include fields: {}. "
+                "Profile dotfile doesn't include fields:\n  {}\n"
                 "Use neosctl -p {} profile init"
-            ).format(field_names, profile_name),
+            ).format("\n  ".join(required_fields), profile_name),
             exit_code=1,
         )
 
